import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import Uploader from '@/components/Uploader';
import { Button, Form, FormItem, Radio, RadioGroup, Icon, Field } from '@antmjs/vantui';
import { saveBind } from '@/services/bind';
import useRequest from '@/utils/useRequest';
import './index.less'

export default (props) => {
  const form = Form.useForm();

  const [loading, request] = useRequest(saveBind);

  const onScan = () => {
    Taro.scanCode({
      success: ({ result }) => {
        form.setFieldsValue('deviceNo', result);
      },
      fail: (err) => {
        console.error(err);
      }
    })
  }

  const onFinish = (errs, values) => {
    console.log(errs, values);
    if (!errs) {
      request(values).then(res => {
        Taro.switchTab({
          url: '/pages/mine/index',
        });
      });
    }
  }

  return (
    <View>
      <Form className="bind-form" form={form} onFinish={onFinish}>
        <FormItem
          required
          label="设备类型"
          name="deviceType"
          validateTrigger="onBlur"
        >
          <RadioGroup direction="horizontal">
            <Radio name="shensong" checkedColor="#07c160">深松</Radio>
            <Radio name="feifang" checkedColor="#07c160">飞防</Radio>
          </RadioGroup>
        </FormItem>
        <FormItem
          required
          label="设备编号"
          name="deviceNo"
          validateTrigger="onBlur"
          renderRight={<View className='scan-btn' onClick={onScan} ><Icon name="scan" size="18px" /></View>}
        >
          <Field placeholder="请输入" clearable />
        </FormItem>
        <FormItem
          required
          label="农机编号"
          name="machineryName"
          validateTrigger="onBlur"
        >
          <Field placeholder="请输入" clearable />
        </FormItem>
        <FormItem
          required
          label="农机图片"
          name="machineryThumb"
        >
          <Uploader />
        </FormItem>
        <FormItem
          required
          label="归 属 人"
          name="userName"
          validateTrigger="onBlur"
        >
          <Field placeholder="请输入" clearable />
        </FormItem>
        <FormItem
          required
          label="手 机 号"
          name="phone"
          validateTrigger="onBlur"
        >
          <Field placeholder="请输入" clearable />
        </FormItem>
        <FormItem
          required
          label="身 份 证"
          name="idCard"
          validateTrigger="onBlur"
        >
          <Field placeholder="请输入" clearable />
        </FormItem>
        <View className="submit-wrapper">
          <Button
            block
            type="primary"
            formType="submit"
            loading={loading}
          >
            提交
          </Button>
        </View>
      </Form>
    </View>
  )
}
