import Taro from '@tarojs/taro'

/**
 * object 转 queryStr
 * @param {*} params 
 * @returns 
 */
 export function getQueryString (params) {
  if (!params) return;

  const keys = Object.keys(params)
  const arr = keys.map((key) => {
    const val = params[key]
    if (val === null || val === undefined) return false;

    return `${key}=${encodeURIComponent(val)}`
  })

  return arr.filter(Boolean).join('&')
}

export function upload(url, tempFilePath) {
  return new Promise((resolve, reject) => {
    Taro.uploadFile({
      // eslint-disable-next-line no-undef
      url: `${HOST}/api/${url}`.replace('api//', 'api/'),
      filePath: tempFilePath,
      name: 'file',
      success: (res) => {
        const { data, code, message } = JSON.parse(res.data);
        if (code === 1000) {
          resolve(data);
        } else {
          reject(message);
          Taro.showToast({
            title: message,
            icon: 'none',
          })
        }
      },
      fail: (err) => {
        console.error(err);
        const errMsg = err.message || err.msg || err.errMsg || err;
        reject(errMsg);
        Taro.showToast({
          title: errMsg,
          icon: 'none',
        })
      }
    });
  });
}


export default (url, options) => {
  const { params, skipError, header, method = 'GET', ...leftOptions } = options || {}
  const queryStr = getQueryString(params)

  const urlWithParams = queryStr ? `${url}?${queryStr}` : url;
  // eslint-disable-next-line no-undef
  const nwUrl = `${HOST}/api/${urlWithParams}`.replace('api//', 'api/');

  const authToken = Taro.getStorageSync('token')
  const tokenHeader = authToken ? { Authorization: authToken } : {}
  const nwHeader = {
    ...(header || {}),
    ...tokenHeader,
  }

  return new Promise((resolve, reject) => {
    Taro.request({
      ...leftOptions,
      url: nwUrl,
      method,
      header: nwHeader,
      success: (res) => {
        const { code, message, data, token } = res.data

        if (token || data?.token) {
          Taro.setStorage({ key: 'token', data: token || data?.token })
        }

        if (code === 1000) {
          resolve(data);

          if (['post', 'put', 'delete'].indexOf(method.toLocaleLowerCase()) > -1) {
            Taro.showToast({
              title: '操作成功',
              icon: 'success',
              duration: 2000
            });            
          }

        } else {
          if (!skipError) {
            Taro.showToast({
              title: message || '网络异常',
              icon: 'none',
            })
          }
          reject(message?.indexOf('java') > -1 ? '系统内部错误' : message)
        }
      },

      fail: (err) => {
        console.error(err)

        const message = err.message || err.errMsg || err || '服务不存在或异常'

        if (!skipError) {
          Taro.showToast({
            title: message,
            icon: 'none',
          })
        }

        reject(message)
      }
    })
  })
}
